@@ -38,9 +38,10 @@ fn cargo(project: &Project) -> Command {
     let mut cmd = raw_cargo();
     cmd.current_dir(&project.dir);
     cmd.envs(cargo_target_dir(project));
-    cmd.envs(rustflags::envs());
+    cmd.env_remove("RUSTFLAGS");
     cmd.env("CARGO_INCREMENTAL", "0");
     cmd.arg("--offline");
+    cmd.arg(format!("--config=build.rustflags={}", rustflags::toml()));
     cmd
 }
 
@@ -182,8 +183,12 @@ fn features(project: &Project) -> Vec<String> {
 }
 
 fn target() -> Vec<&'static str> {
+    #[cfg(not(host_os = "windows"))]
     const TARGET: Option<&str> = include!(concat!(env!("OUT_DIR"), "/target"));
 
+    #[cfg(host_os = "windows")]
+    const TARGET: Option<&str> = include!(concat!(env!("OUT_DIR"), "\\target"));
+
     // When --target flag is passed, cargo does not pass RUSTFLAGS to rustc when
     // building proc-macro and build script even if the host and target triples
     // are the same. Therefore, if we always pass --target to cargo, tools such
