@@ -5,7 +5,7 @@ use std::io;
 use std::path::PathBuf;
 
 #[derive(Debug)]
-pub enum Error {
+pub(crate) enum Error {
     Cargo(io::Error),
     CargoFail,
     GetManifest(PathBuf, Box<Error>),
@@ -20,12 +20,13 @@ pub enum Error {
     ReadStderr(io::Error),
     RunFailed,
     ShouldNotHaveCompiled,
-    Toml(basic_toml::Error),
+    TomlDe(toml::de::Error),
+    TomlSer(toml::ser::Error),
     UpdateVar(OsString),
     WriteStderr(io::Error),
 }
 
-pub type Result<T> = std::result::Result<T, Error>;
+pub(crate) type Result<T> = std::result::Result<T, Error>;
 
 impl Display for Error {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
@@ -48,7 +49,8 @@ impl Display for Error {
             ShouldNotHaveCompiled => {
                 write!(f, "expected test case to fail to compile, but it succeeded")
             }
-            Toml(e) => write!(f, "{}", e),
+            TomlDe(e) => write!(f, "{}", e),
+            TomlSer(e) => write!(f, "{}", e),
             UpdateVar(var) => write!(
                 f,
                 "unrecognized value of TRYBUILD: {:?}",
@@ -88,8 +90,14 @@ impl From<io::Error> for Error {
     }
 }
 
-impl From<basic_toml::Error> for Error {
-    fn from(err: basic_toml::Error) -> Self {
-        Error::Toml(err)
+impl From<toml::de::Error> for Error {
+    fn from(err: toml::de::Error) -> Self {
+        Error::TomlDe(err)
+    }
+}
+
+impl From<toml::ser::Error> for Error {
+    fn from(err: toml::ser::Error) -> Self {
+        Error::TomlSer(err)
     }
 }
