@@ -208,9 +208,10 @@
 //! makes error messages that we care about substantially worse, it is also
 //! important to catch and report as a compiler issue.
 
-#![doc(html_root_url = "https://docs.rs/trybuild/1.0.91")]
+#![doc(html_root_url = "https://docs.rs/trybuild/1.0.99")]
 #![allow(
     clippy::collapsible_if,
+    clippy::comparison_chain,
     clippy::default_trait_access,
     clippy::derive_partial_eq_without_eq,
     clippy::doc_markdown,
@@ -231,6 +232,7 @@
     clippy::too_many_lines,
     clippy::trivially_copy_pass_by_ref,
     clippy::uninhabited_references,
+    clippy::uninlined_format_args,
     clippy::unused_self,
     clippy::while_let_on_iterator,
 )]
