@@ -5,10 +5,10 @@ use crate::env::Update;
 use crate::error::{Error, Result};
 use crate::expand::{expand_globs, ExpandedTest};
 use crate::flock::Lock;
-use crate::manifest::{Bin, Build, Config, Manifest, Name, Package, Workspace};
+use crate::manifest::{Bin, Manifest, Name, Package, Workspace};
 use crate::message::{self, Fail, Warn};
 use crate::normalize::{self, Context, Variations};
-use crate::{features, rustflags, Expected, Runner, Test};
+use crate::{features, Expected, Runner, Test};
 use serde_derive::Deserialize;
 use std::collections::{BTreeMap as Map, BTreeSet as Set};
 use std::env;
@@ -182,12 +182,6 @@ impl Runner {
 
     fn write(&self, project: &mut Project) -> Result<()> {
         let manifest_toml = toml::to_string(&project.manifest)?;
-
-        let config = self.make_config();
-        let config_toml = toml::to_string(&config)?;
-
-        fs::create_dir_all(path!(project.dir / ".cargo"))?;
-        fs::write(path!(project.dir / ".cargo" / "config.toml"), config_toml)?;
         fs::write(path!(project.dir / "Cargo.toml"), manifest_toml)?;
 
         let main_rs = b"\
@@ -243,7 +237,7 @@ impl Runner {
                     version: None,
                     path: Some(source_dir.clone()),
                     optional: false,
-                    default_features: false,
+                    default_features: Some(false),
                     features: Vec::new(),
                     git: None,
                     branch: None,
@@ -264,9 +258,8 @@ impl Runner {
         let mut features = source_manifest.features;
         for (feature, enables) in &mut features {
             enables.retain(|en| {
-                let dep_name = match en.strip_prefix("dep:") {
-                    Some(dep_name) => dep_name,
-                    None => return false,
+                let Some(dep_name) = en.strip_prefix("dep:") else {
+                    return false;
                 };
                 if let Some(Dependency { optional: true, .. }) = dependencies.get(dep_name) {
                     return true;
@@ -324,14 +317,6 @@ impl Runner {
         Ok(manifest)
     }
 
-    fn make_config(&self) -> Config {
-        Config {
-            build: Build {
-                rustflags: rustflags::make_vec(),
-            },
-        }
-    }
-
     fn run_all(&self, project: &Project, tests: Vec<ExpandedTest>) -> Result<Report> {
         let mut report = Report {
             failures: 0,
@@ -622,9 +607,8 @@ fn parse_cargo_json(
     let mut remaining = &*String::from_utf8_lossy(stdout);
     let mut seen = Set::new();
     while !remaining.is_empty() {
-        let begin = match remaining.find("{\"reason\":") {
-            Some(begin) => begin,
-            None => break,
+        let Some(begin) = remaining.find("{\"reason\":") else {
+            break;
         };
         let (nonmessage, rest) = remaining.split_at(begin);
         nonmessage_stdout.push_str(nonmessage);
@@ -643,9 +627,8 @@ fn parse_cargo_json(
         }
         if let Ok(de) = serde_json::from_str::<CargoMessage>(message) {
             if de.message.level != "failure-note" {
-                let (name, test) = match path_map.get(&de.target.src_path) {
-                    Some(test) => test,
-                    None => continue,
+                let Some((name, test)) = path_map.get(&de.target.src_path) else {
+                    continue;
                 };
                 let entry = map
                     .entry(de.target.src_path)
